# Building the docs

## via Makefile

`make docs` from root of project

NOTE: do not commit generated files

## via ReadTheDocs

https://readthedocs.org/projects/duplicity/builds/

NOTE: should run automatically when repo changes

# setup

https://gitlab.com/duplicity/duplicity/-/blob/main/docs/conf.py
https://gitlab.com/duplicity/duplicity/-/blob/main/readthedocs.yaml
